import setuptools 

with open("README.md", "r") as fh: 
	description = fh.read() 

setuptools.setup( 
	name="oms-test-package", 
	version="0.0.1", 
	author="Saurabh Hagawane", 
	author_email="hagawane7354@gmail.com", 
	packages=["oms_test_package"], 
	description="A sample test package", 
	long_description=description, 
	long_description_content_type="text/markdown", 
	url="https://github.com/wte-dev/python-package.git", 
	license='MIT', 
	python_requires='>=3.8', 
	install_requires=[] 
) 
